@@ -1,5 +1,7 @@
+from uplink import decorators
 from uplink.decorators import MethodAnnotation
-from uplink.clients.io import RequestTemplate
+# from uplink.clients.io import RequestTemplate
+
 
 class CachingTemplate(decorators.RequestTemplate):
     def __init__(self, cache, base_url, hours):
@@ -11,7 +13,7 @@ class CachingTemplate(decorators.RequestTemplate):
         method, url, params = request
         urlpath = url.replace(self._base_url, '')
         try:
-            loaded_data =self._cache.load_cached(urlpath, self._hours)
+            loaded_data = self._cache.load_cached(urlpath, self._hours)
             resp = Response()
             resp.status_code = 200
             resp._content = loaded_data
@@ -32,4 +34,4 @@ class cache(MethodAnnotation):
     def modify_request(self, request_builder):
         cache = getattr(request_builder.client, '_cache', None)
         if cache:
-            request_builder.add_request_template(CachingTemplate(cache, request_builder.base_url, self._cache_hours))
\ No newline at end of file
+            request_builder.add_request_template(CachingTemplate(cache, request_builder.base_url, self._cache_hours))
